<?php

// My Click Boss - Version 3.0
// Copyright (c) 2013 by RLW Publishing, all rights reserved.
// http://myclickboss.com/

function sanitize($data, $mysqlconn) {
	// remove whitespaces (not a must though)
	$data = trim($data);

	// apply stripslashes if magic_quotes_gpc is enabled
	if(get_magic_quotes_gpc()) {
		$data = stripslashes($data);
	}

	// a mySQL connection is required before using this function
	$data = mysqli_real_escape_string($mysqlconn, $data);

	return $data;
}

// get surfers real IP address if possible
// $ip = GetUserIP();
function GetUserIP() {
	if (isset($_SERVER)) {
		if (isset($_SERVER["HTTP_X_FORWARDED_FOR"]))
			return $_SERVER["HTTP_X_FORWARDED_FOR"];
		if (isset($_SERVER["HTTP_CLIENT_IP"]))
			return $_SERVER["HTTP_CLIENT_IP"];
		return $_SERVER["REMOTE_ADDR"];
	}
	if (getenv('HTTP_X_FORWARDED_FOR'))
		return getenv('HTTP_X_FORWARDED_FOR');
	if (getenv('HTTP_CLIENT_IP'))
		return getenv('HTTP_CLIENT_IP');
	return getenv('REMOTE_ADDR');
}

function valid_email($email) {
    if(preg_match('/^([0-9,a-z,A-Z]+)([.,_,-]([0-9,a-z,A-Z]+))*[@]([0-9,a-z,A-Z]+)([.,_,-]([0-9,a-z,A-Z]+))*[.]([0-9,a-z,A-Z]){2}([0-9,a-z,A-Z])*$/',$email)) {
        return TRUE;
    } else {
        return FALSE;
    }
}

function url_exists($url) {
	$ch = @curl_init($url);
	@curl_setopt($ch, CURLOPT_HEADER, TRUE);
	@curl_setopt($ch, CURLOPT_NOBODY, TRUE);
	@curl_setopt($ch, CURLOPT_FOLLOWLOCATION, FALSE);
	@curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
	$status = array ();
	preg_match('/HTTP\/.* ([0-9]+) .*/', @curl_exec($ch), $status);
	return ($status [1] == 200);
}

// $link_count = count_links($page);
function count_links($page) { 
	$xml = new DOMDocument(); 
	@$xml->loadHTML($page); 
	$link_count = 0; 
	foreach($xml->getElementsByTagName('a') as $link) { 
		$href = $link->getAttribute('href');
		$link_count++;
	} 
	return $link_count; 
}

// $links_found = getLinks($page);
function getLinks($page) {
	// return array
	$ret = array();
	// a new dom object
	$dom = new domDocument();
	// get the HTML (suppress errors)
	@$dom->loadHTML($page);
	// remove silly white space
	$dom->preserveWhiteSpace = false;
	// get the links from the HTML
	$links = $dom->getElementsByTagName('a');
	// loop over the links
	foreach ($links as $tag) {
		$ret[$tag->getAttribute('href')] = $tag->childNodes->item(0)->nodeValue;
	}
	return $ret;
}

function valid_url($str) {
	// (http|https|ftp)
	return ( ! preg_match('/^(http|https):\/\/([A-Z0-9][A-Z0-9_-]*(?:\.[A-Z0-9][A-Z0-9_-]*)+):?(\d+)?\/?/i', $str)) ? FALSE : TRUE;
}

function sec_session_start() {
	$session_name = 'members_27744590237_session'; // Set a custom session name
	$secure = false; // Set to true if using https.
	$httponly = true; // This stops javascript being able to access the session id. 
 
	ini_set('session.use_only_cookies', 1); // Forces sessions to only use cookies. 
	$cookieParams = session_get_cookie_params(); // Gets current cookies params.
	session_set_cookie_params($cookieParams["lifetime"], $cookieParams["path"], $cookieParams["domain"], $secure, $httponly); 
	session_name($session_name); // Sets the session name to the one set above.
	session_start(); // Start the php session
	session_regenerate_id(true); // regenerated the session, delete the old one.     
}

function login($email, $password, $mysqli) {
	// Using prepared Statements means that SQL injection is not possible. 
	if ($stmt = $mysqli->prepare("SELECT id, username, password, salt FROM members WHERE email = ? LIMIT 1")) { 
		$stmt->bind_param('s', $email); // Bind "$email" to parameter.
		$stmt->execute(); // Execute the prepared query.
		$stmt->store_result();
		$stmt->bind_result($members_id, $username, $db_password, $salt); // get variables from result.
		$stmt->fetch();
		$password = hash('sha512', $password.$salt); // hash the password with the unique salt.
		if($stmt->num_rows == 1) { // If the user exists
			// We check if the account is locked from too many login attempts
			if(checkbrute($members_id, $mysqli) == true) { 
				// Account is locked
				// Send an email to user saying their account is locked
				return false;
			} else {
				if($db_password == $password) { // Check if password in database matches password the user submitted. 
					// Password is correct!
					$ip_address = $_SERVER['REMOTE_ADDR']; // Get the IP address of the user. 
					$user_browser = $_SERVER['HTTP_USER_AGENT']; // Get the user-agent string of the user.
					$members_id = preg_replace("/[^0-9]+/", "", $members_id); // XSS protection as we might print this value
					$_SESSION['members_id'] = $members_id; 
					$username = preg_replace("/[^a-zA-Z0-9_\-]+/", "", $username); // XSS protection might print this value
					$_SESSION['username'] = $username;
					$_SESSION['login_string'] = hash('sha512', $password.$ip_address.$user_browser);
					// Login successful.
					return true;    
				} else {
					// Password is not correct
					// We record this attempt in the database
					$now = time();
					$mysqli->query("INSERT INTO login_attempts (members_id, time) VALUES ('$members_id', '$now')");
					return false;
				}
			}
		} else {
			// No user exists. 
			return false;
		}
	}
}

function checkbrute($members_id, $mysqli) {
	// Get timestamp of current time
	$now = time();
	// All login attempts are counted from the past 2 hours. 
	$valid_attempts = $now - (2 * 60 * 60); 
 
	if ($stmt = $mysqli->prepare("SELECT time FROM login_attempts WHERE members_id = ? AND time > '$valid_attempts'")) { 
		$stmt->bind_param('i', $members_id); 
		// Execute the prepared query.
		$stmt->execute();
		$stmt->store_result();
		// If there has been more than 5 failed logins
		if($stmt->num_rows > 5) {
			return true;
		} else {
			return false;
		}
	}
}

function login_check($mysqli) {
	// Check if all session variables are set
	if(isset($_SESSION['members_id'], $_SESSION['username'], $_SESSION['login_string'])) {
		$members_id = $_SESSION['members_id'];
		$login_string = $_SESSION['login_string'];
		$username = $_SESSION['username'];
		$ip_address = $_SERVER['REMOTE_ADDR']; // Get the IP address of the user. 
		$user_browser = $_SERVER['HTTP_USER_AGENT']; // Get the user-agent string of the user.
 
		if ($stmt = $mysqli->prepare("SELECT password FROM members WHERE id = ? LIMIT 1")) { 
			$stmt->bind_param('i', $members_id); // Bind "$members_id" to parameter.
			$stmt->execute(); // Execute the prepared query.
			$stmt->store_result();
 
			if($stmt->num_rows == 1) { // If the user exists
				$stmt->bind_result($password); // get variables from result.
				$stmt->fetch();
				$login_check = hash('sha512', $password.$ip_address.$user_browser);
				if($login_check == $login_string) {
					// Logged In!!!!
					return true;
				} else {
					// Not logged in
					return false;
				}
			} else {
				// Not logged in
				return false;
			}
		} else {
			// Not logged in
			return false;
		}
	} else {
		// Not logged in
		return false;
	}
}

?>
