<?php

// My Click Boss - Version 3.11
// Copyright (c) 2013 by RLW Publishing, all rights reserved.
// http://myclickboss.com/

$password = "";
$username = "";
$email = "";
$security_code = "";
$security_code2 = "";

include "config.inc.php";

$mysqli = new mysqli(HOST, USER, PASSWORD, DATABASE);
if ($mysqli->connect_errno) {
	echo "Failed to connect to MySQL: (" . $mysqli->connect_errno . ") " . $mysqli->connect_error;
	exit();
}

// system configuration
$sql = "CREATE TABLE script_configuration (
  id int(10) unsigned NOT NULL auto_increment,
  db_version varchar(255) NOT NULL default '',
  script_version varchar(255) NOT NULL default '',
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// create base script_configuration record
$sql = "INSERT INTO script_configuration (db_version, script_version) values ('3.1', '3.1')";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table insert failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// members
$sql = "CREATE TABLE members (
  id int(10) unsigned NOT NULL auto_increment,
  username varchar(255) NOT NULL default '',
  email varchar(255) NOT NULL default '',
  password char(128) NOT NULL default '',
  salt char(128) NOT NULL default '',
  member_name varchar(255) NOT NULL default '',
  security_code varchar(255) NOT NULL default '',
  security_code2 varchar(255) NOT NULL default '',
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// add login information
// hash it if not done in js from form
$password = hash('sha512', $password);
// Create a random salt
$random_salt = hash('sha512', uniqid(mt_rand(1, mt_getrandmax()), true));
// Create salted password (Careful not to over season)
$password = hash('sha512', $password.$random_salt);
// Make sure you use prepared statements!
if ($insert_stmt = $mysqli->prepare("INSERT INTO members (username, email, password, salt, security_code, security_code2) VALUES (?, ?, ?, ?, ?, ?)")) {    
   $insert_stmt->bind_param('ssssss', $username, $email, $password, $random_salt, $security_code, $security_code2); 
   // Execute the prepared query.
   $insert_stmt->execute();
}

// script_settings
$sql = "CREATE TABLE script_settings (
  id int(10) unsigned NOT NULL auto_increment,
  daily_click_count_last_reset date NOT NULL default '0000-00-00',
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

$sql = "INSERT INTO script_settings (daily_click_count_last_reset) values (now())";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table insert failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// click_rotators
$sql = "CREATE TABLE click_rotators (
  id int(10) unsigned NOT NULL auto_increment,
  description varchar(255) NOT NULL default '',
  rotator_type varchar(255) NOT NULL default 'Series',
  default_url text NOT NULL,
  rotator_click_tracking_code varchar(255) NOT NULL default '',
  notes text NOT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// click_rotator_links
// daily_click_limit maximum number of clicks to send each day
// daily_click_count current number of clicks sent today
$sql = "CREATE TABLE click_rotator_links (
  id int(10) unsigned NOT NULL auto_increment,
  click_rotators_id int(10) unsigned NOT NULL default '0',
  series_position int(10) unsigned NOT NULL default '0',
  link_description varchar(255) NOT NULL default '',
  link_url text NOT NULL,
  total_clicks_to_send int(10) unsigned NOT NULL default '0',
  total_clicks_sent int(10) unsigned NOT NULL default '0',
  date_last_click_sent datetime NOT NULL default '0000-00-00 00:00:00',
  country_codes_accepted text NOT NULL,
  country_codes_not_accepted text NOT NULL, 
  link_status varchar(15) NOT NULL default 'Active',
  start_date_time datetime NOT NULL default '0000-00-00 00:00:00',
  end_date_time datetime NOT NULL default '0000-00-00 00:00:00',
  daily_click_limit int(10) unsigned NOT NULL default '0',
  daily_click_count int(10) unsigned NOT NULL default '0', 
  click_trades_i_code varchar(255) NOT NULL default '',
  notes text NOT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// click_rotator_stats
$sql = "CREATE TABLE click_rotator_stats (
  id int(10) unsigned NOT NULL auto_increment,
  click_rotators_id int(10) unsigned NOT NULL default '0',
  click_rotator_links_id int(10) unsigned NOT NULL default '0',
  click_date datetime NOT NULL default '0000-00-00 00:00:00',
  surfer_ip varchar(255) NOT NULL default '',
  referring_url text NOT NULL,
  country_code varchar(255) NOT NULL default '',
  country_name varchar(255) NOT NULL default '',
  language_code varchar(255) NOT NULL default '',
  user_agent varchar(255) NOT NULL default '',
  ip_host text NOT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// click_trackers
// click_tracker_type = I,O inbound or outbound
// tracker_status = Active, Archived
$sql = "CREATE TABLE click_trackers (
  id int(10) unsigned NOT NULL auto_increment,
  description varchar(255) NOT NULL default '',
  click_tracker_type varchar(1) NOT NULL default '',
  url text NOT NULL,
  maximum_clicks int(10) unsigned NOT NULL default '0',
  secondary_url text NOT NULL,
  date_click_tracker_created datetime NOT NULL default '0000-00-00 00:00:00',
  click_tracking_code varchar(255) NOT NULL default '',
  total_clicks int(10) unsigned NOT NULL default '0',
  tracker_status varchar(255) NOT NULL default 'Active',
  country_codes_accepted text NOT NULL,
  country_codes_not_accepted text NOT NULL, 
  stats_password varchar(255) NOT NULL default '',
  alert_when_number_clicks_sent int(10) unsigned NOT NULL default '0',
  email_alert_sent varchar(3) NOT NULL default 'No',
  notes text NOT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// click_tracker_stats (unique IP)
$sql = "CREATE TABLE click_tracker_stats (
  id int(10) unsigned NOT NULL auto_increment,
  click_trackers_id int(10) unsigned NOT NULL default '0',
  click_date datetime NOT NULL default '0000-00-00 00:00:00',
  surfer_ip varchar(255) NOT NULL default '',
  referring_url text NOT NULL,
  country_code varchar(255) NOT NULL default '',
  country_name varchar(255) NOT NULL default '',
  language_code varchar(255) NOT NULL default '',
  user_agent varchar(255) NOT NULL default '',
  ip_host text NOT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// click_tracker_raw_stats (raw duplicate IPs)
$sql = "CREATE TABLE click_tracker_raw_stats (
  id int(10) unsigned NOT NULL auto_increment,
  click_trackers_id int(10) unsigned NOT NULL default '0',
  click_date datetime NOT NULL default '0000-00-00 00:00:00',
  surfer_ip varchar(255) NOT NULL default '',
  referring_url text NOT NULL,
  country_code varchar(255) NOT NULL default '',
  country_name varchar(255) NOT NULL default '',
  language_code varchar(255) NOT NULL default '',
  user_agent varchar(255) NOT NULL default '',
  ip_host text NOT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// click_trades
// inbound_click_tracking_code and outbound_click_tracking_code must be unique to itself with i,o added
// trade_status = Active, Archived
$sql = "CREATE TABLE click_trades (
  id int(10) unsigned NOT NULL auto_increment,
  description varchar(255) NOT NULL default '',
  trade_partners_url text NOT NULL,
  my_url text NOT NULL,
  date_click_trade_created datetime NOT NULL default '0000-00-00 00:00:00',
  inbound_click_tracking_code varchar(255) NOT NULL default '',
  outbound_click_tracking_code varchar(255) NOT NULL default '',
  total_clicks_received int(10) unsigned NOT NULL default '0',
  total_clicks_sent int(10) unsigned NOT NULL default '0',
  alert_when_number_clicks_sent int(10) unsigned NOT NULL default '0',
  email_alert_sent varchar(3) NOT NULL default 'No',
  trade_partners_stats_password varchar(255) NOT NULL default '',
  trade_status varchar(255) NOT NULL default 'Active',
  notes text NOT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// click trade_stats (unique IP)
// inbound_outbound = i or o
$sql = "CREATE TABLE click_trade_stats (
  id int(10) unsigned NOT NULL auto_increment,
  click_trades_id int(10) unsigned NOT NULL default '0',
  inbound_outbound varchar(1) NOT NULL default '',
  click_date datetime NOT NULL default '0000-00-00 00:00:00',
  surfer_ip varchar(255) NOT NULL default '',
  referring_url text NOT NULL,
  country_code varchar(255) NOT NULL default '',
  country_name varchar(255) NOT NULL default '',
  language_code varchar(255) NOT NULL default '',
  user_agent varchar(255) NOT NULL default '',
  ip_host text NOT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// click trade_stats RAW
// inbound_outbound = i or o
$sql = "CREATE TABLE click_trade_raw_stats (
  id int(10) unsigned NOT NULL auto_increment,
  click_trades_id int(10) unsigned NOT NULL default '0',
  inbound_outbound varchar(1) NOT NULL default '',
  click_date datetime NOT NULL default '0000-00-00 00:00:00',
  surfer_ip varchar(255) NOT NULL default '',
  referring_url text NOT NULL,
  country_code varchar(255) NOT NULL default '',
  country_name varchar(255) NOT NULL default '',
  language_code varchar(255) NOT NULL default '',
  user_agent varchar(255) NOT NULL default '',
  ip_host text NOT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// pixel_stats
// tracker_type = (a)click_trackers or (b)click_trades (n) none
// tracker_id = id of tracker type (0 if none)
$sql = "CREATE TABLE pixel_stats (
  id int(10) unsigned NOT NULL auto_increment,
  tracker_type varchar(10) NOT NULL default '',
  tracker_id int(10) unsigned NOT NULL default '0',
  surfer_ip varchar(255) NOT NULL default '',
  pixel_fire_date datetime NOT NULL default '0000-00-00 00:00:00',
  pixel_location_slug varchar(255) NOT NULL default '',
  referring_url text NOT NULL,
  country_code varchar(255) NOT NULL default '',
  country_name varchar(255) NOT NULL default '',
  language_code varchar(255) NOT NULL default '',
  user_agent varchar(255) NOT NULL default '',
  ip_host text NOT NULL,
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

// login_attempts
$sql = "CREATE TABLE login_attempts (
  id int(10) unsigned NOT NULL auto_increment,
  members_id int(10) unsigned NOT NULL default '0',
  time varchar(30) NOT NULL default '',
  login_attempt_ip varchar(255) NOT NULL default '',
  PRIMARY KEY (id)
) ENGINE=InnoDB";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Table creation failed: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}

echo "Installation Complete!";

$mysqli->close();

?>
