<?php
header("Cache-Control: no-cache, must-revalidate");
header("Expires: Sat, 26 Jul 1997 05:00:00 GMT");
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache");

// My Click Boss - Version 3.11
// Copyright (c) 2013 by RLW Publishing, all rights reserved.
// http://myclickboss.com/

include "admin/config.inc.php";
include "admin/functions.php";
include("geoip.inc");

$default_404_url = $rotator_404_url;

// get a (click_tracking_code)
if (isset($_GET['a'])) {
	$click_tracking_code = $_GET['a'];
} else {
	$click_tracking_code = "";
}

// get surfers IP
$surfer_ip_address = GetUserIP();

// get referring url
if (isset($_SERVER['HTTP_REFERER'])) {
	$referring_url = $_SERVER['HTTP_REFERER'];
} else {
	$referring_url = "";
}

// get $_SERVER['HTTP_ACCEPT_LANGUAGE']
if (isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
	$accept_language_string = $_SERVER['HTTP_ACCEPT_LANGUAGE'];
} else {
	$accept_language_string = "";
}

// get $_SERVER['HTTP_USER_AGENT']
if (isset($_SERVER['HTTP_USER_AGENT'])) {
	$user_agent_string = $_SERVER['HTTP_USER_AGENT'];
} else {
	$user_agent_string = "";
}

// get $_SERVER['REMOTE_HOST']
if (isset($_SERVER['REMOTE_HOST'])) {
	$ip_host = $_SERVER['REMOTE_HOST'];
} else {
	$ip_host = "";
}

// is $click_tracking_code blank?
if ($click_tracking_code == "") {
	// redirect to url with a 301
	//header("HTTP/1.1 301 Moved Permanently");
	header("Location: $default_404_url");
	exit();
}

// $click_tracking_code contain invalid characters?
if(!preg_match('/^[a-z0-9-]+$/', $click_tracking_code)) {
	// redirect to url with a 301
	//header("HTTP/1.1 301 Moved Permanently");
	header("Location: $default_404_url");
	exit();
}

// is code a rotator code?
// get first character of code
$tracking_code_type = substr($click_tracking_code, 0, 1);
if ($tracking_code_type != "r") {
	// redirect to url with a 301
	//header("HTTP/1.1 301 Moved Permanently");
	header("Location: $default_404_url");
	exit();
}

// connect to database
$mysqli = new mysqli(HOST, USER, PASSWORD, DATABASE);
if ($mysqli->connect_errno) {
	echo "Failed to connect to MySQL: (" . $mysqli->connect_errno . ") " . $mysqli->connect_error;
	exit();
}

// does daily_click_count need to be reset?
$sql = "SELECT * FROM script_settings";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Could not select record in script_settings: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}
$row = $result->fetch_array(MYSQLI_BOTH);
$script_settings_id = $row['id'];
$daily_click_count_last_reset = $row['daily_click_count_last_reset'];
$result->close();
$todays_current_date = date("Y-m-d");
if ($daily_click_count_last_reset != $todays_current_date) {
	// reset counts
	$sql = "UPDATE click_rotator_links SET daily_click_count = 0";
	$result = $mysqli->query($sql);
	if ($mysqli->connect_errno) {
		echo "Could not update record in click_rotator_links: (" . $mysqli->errno . ") " . $mysqli->error;
		exit();
	}
	// set new date
	$sql = "UPDATE script_settings SET daily_click_count_last_reset = now() WHERE id = $script_settings_id";
	$result = $mysqli->query($sql);
	if ($mysqli->connect_errno) {
		echo "Could not update record in script_settings: (" . $mysqli->errno . ") " . $mysqli->error;
		exit();
	}	
}

// sanitize all input data
$click_tracking_code = sanitize($click_tracking_code, $mysqli);
$referring_url = sanitize($referring_url, $mysqli);
$accept_language_string = sanitize($accept_language_string, $mysqli);
$user_agent_string = sanitize($user_agent_string, $mysqli);

// lookup tracking code. Is it valid?
$sql = "SELECT * FROM click_rotators WHERE rotator_click_tracking_code = '$click_tracking_code'";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Could not select record in click_rotators: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}
$count = $result->num_rows;
if ($count < 1) {
	// close up shop
	$mysqli->close();
	// redirect to url with a 301
	//header("HTTP/1.1 301 Moved Permanently");
	header("Location: $default_404_url");
	exit();
}
// get the data for this click_rotators
$row = $result->fetch_array(MYSQLI_BOTH);
$click_rotators_id = $row['id'];
$rotator_type = $row['rotator_type'];
$default_url = stripslashes($row['default_url']);
$result->close();

// get GEO data
$gi = geoip_open("$path_to_geoip",GEOIP_STANDARD);
$country_code = geoip_country_code_by_addr($gi, $surfer_ip_address);
$country_name = geoip_country_name_by_addr($gi, $surfer_ip_address);
geoip_close($gi);

// set the default destination URL and link id
$destination_url = $default_url;
//$destination_url_click_rotator_links_id = 0;

// if IP is in stats, send surfer to next link. Not the same one.
// set the destination URL if a appropriate link is found along with the rotator links id

// what is the rotator_type?
if ($rotator_type == "Series") {
	// Series (order by series_position)
	// get first link in series that has not had quota filled
	// if all link quotas have been filled, send to default url
	// has surfer been to this link? If so, send to first link he has not gone to
	// if he has gone to all links, send to default url

	$sql = "SELECT * FROM click_rotator_links WHERE click_rotators_id = $click_rotators_id && link_status = 'Active' && start_date_time <= now() ORDER BY series_position ASC";
	$result = $mysqli->query($sql);
	if ($mysqli->connect_errno) {
		echo "Could not select record in click_rotator_links: (" . $mysqli->errno . ") " . $mysqli->error;
		exit();
	}
	// loop through links and see if one is found to send surfer (quota not filled)
	// break out when found
	$link_found = "No";
	while ($row = $result->fetch_array(MYSQLI_BOTH)) {
		$click_rotator_links_id = $row['id'];
		$series_position = $row['series_position'];
		$link_url = stripslashes($row['link_url']);
		$total_clicks_to_send = $row['total_clicks_to_send'];
		$total_clicks_sent = $row['total_clicks_sent'];
		$date_last_click_sent = $row['date_last_click_sent'];
		$end_date_time = $row['end_date_time'];
		$country_codes_accepted = $row['country_codes_accepted'];
		$country_codes_not_accepted = $row['country_codes_not_accepted'];
		$click_trades_i_code = $row['click_trades_i_code'];
		$daily_click_limit = $row['daily_click_limit'];
		$daily_click_count = $row['daily_click_count'];

		// check end date and time to see if it has passed
		if ($end_date_time != "0000-00-00 00:00:00") {
			if(time() > strtotime($end_date_time)) {
				continue;
			}
		}

		// does rotator link allow or not allow country code?
		// is $country_code blank? then skip this check
		if ($country_code != "") {
			// $country_codes_accepted (not blank)
			if ($country_codes_accepted != "") {
				// is $country_code NOT in $country_codes_accepted
				if(stripos($country_codes_accepted, $country_code) === false) {
					continue;
				}
			}
			// $country_codes_not_accepted (not blank)
			if ($country_codes_not_accepted != "") {
				// is $country_code in $country_codes_not_accepted
				if(stripos($country_codes_not_accepted, $country_code) !== false) {
					continue;
				}
			}
		}

		// check quota
		if ($total_clicks_sent >= $total_clicks_to_send) {
			continue;
		}
		
		// check daily click limit
		if ($daily_click_limit > 0) {
			if ($daily_click_count >= $daily_click_limit) {
				continue;
			}
		}
		
		// has surfer been to this link?
		$sql2 = "SELECT * FROM click_rotator_stats WHERE click_rotator_links_id = $click_rotator_links_id && surfer_ip = '$surfer_ip_address'";
		$result2 = $mysqli->query($sql2);
		if ($mysqli->connect_errno) {
			echo "Could not select record in click_rotator_stats: (" . $mysqli->errno . ") " . $mysqli->error;
			exit();
		}
		$count2 = $result2->num_rows;
		//$result2->close();
		if ($count2 > 0) {
			continue;
		}
		// did surfer come from this link?
		if ($click_trades_i_code != "") {
			// get click trade record if any
			$sql2 = "SELECT * FROM click_trades WHERE inbound_click_tracking_code = '$click_trades_i_code'";
			$result2 = $mysqli->query($sql2);
			if ($mysqli->connect_errno) {
				echo "Could not select record in click_trades: (" . $mysqli->errno . ") " . $mysqli->error;
				exit();
			}
			$count2 = $result2->num_rows;
			if ($count2 > 0) {
				$row2 = $result2->fetch_array(MYSQLI_BOTH);
				$click_trades_id = $row2['id'];		
				$sql3 = "SELECT * FROM click_trade_stats WHERE click_trades_id = $click_trades_id && inbound_outbound = 'i' && surfer_ip = '$surfer_ip_address'";
				$result3 = $mysqli->query($sql3);
				if ($mysqli->connect_errno) {
					echo "Could not select record in click_trade_stats: (" . $mysqli->errno . ") " . $mysqli->error;
					exit();
				}
				$count3 = $result3->num_rows;
				//$result3->close();
				if ($count3 > 0) {
					//$result2->close();
					continue;
				}
			}
			//$result2->close();
		}
		// found a link to send surfer to
		$destination_url = $link_url;
		$link_found = "Yes";
		break;
	} // end while
	//$result->close();
} else {
	// Rotate (order by series_position but look at date field also)
	// get next link in rotation that has not had quota filled.
	// If surfer has been here, send to next link he has not gone to that has not had quota filled
	// if surfer has gone to all links, or all quotas are filled send to default url
	// get number of links in rotator
	$sql = "SELECT * FROM click_rotator_links WHERE click_rotators_id = $click_rotators_id && link_status = 'Active' && start_date_time <= now() ORDER BY date_last_click_sent DESC";
	$result = $mysqli->query($sql);
	if ($mysqli->connect_errno) {
		echo "Could not select record in click_rotator_links: (" . $mysqli->errno . ") " . $mysqli->error;
		exit();
	}
	$number_links = $result->num_rows;
	// get series_position of last link used
	$row = $result->fetch_array(MYSQLI_BOTH);
	$last_sent_series_position = $row['series_position'];	
	$result->close();
	// get links in series_position order (may have to go through twice)
	$sql = "SELECT * FROM click_rotator_links WHERE click_rotators_id = $click_rotators_id && link_status = 'Active' ORDER BY series_position ASC";
	$result = $mysqli->query($sql);
	if ($mysqli->connect_errno) {
		echo "Could not select record in click_rotator_links: (" . $mysqli->errno . ") " . $mysqli->error;
		exit();
	}
	// loop through links and see if one is found to send surfer (quota not filled)
	// break out when found
	$link_found = "No";
	while ($row = $result->fetch_array(MYSQLI_BOTH)) {
		$click_rotator_links_id = $row['id'];
		$series_position = $row['series_position'];
		$link_url = stripslashes($row['link_url']);
		$total_clicks_to_send = $row['total_clicks_to_send'];
		$total_clicks_sent = $row['total_clicks_sent'];
		$date_last_click_sent = $row['date_last_click_sent'];
		$end_date_time = $row['end_date_time'];
		$country_codes_accepted = $row['country_codes_accepted'];
		$country_codes_not_accepted = $row['country_codes_not_accepted'];
		$click_trades_i_code = $row['click_trades_i_code'];
		$daily_click_limit = $row['daily_click_limit'];
		$daily_click_count = $row['daily_click_count'];

		// skip to +1 greater than $last_sent_series_position
		if ($series_position <= $last_sent_series_position) {
			continue;
		}
		
		// check end date and time to see if it has passed
		if ($end_date_time != "0000-00-00 00:00:00") {
			if(time() > strtotime($end_date_time)) {
				continue;
			}
		}

		// does rotator link allow or not allow country code?
		// is $country_code blank? then skip this check
		if ($country_code != "") {
			// $country_codes_accepted (not blank)
			if ($country_codes_accepted != "") {
				// is $country_code NOT in $country_codes_accepted
				if(stripos($country_codes_accepted, $country_code) === false) {
					continue;
				}
			}
			// $country_codes_not_accepted (not blank)
			if ($country_codes_not_accepted != "") {
				// is $country_code in $country_codes_not_accepted
				if(stripos($country_codes_not_accepted, $country_code) !== false) {
					continue;
				}
			}
		}
		
		// check quota
		if ($total_clicks_sent >= $total_clicks_to_send) {
			continue;
		}
		
		// check daily click limit
		if ($daily_click_limit > 0) {
			if ($daily_click_count >= $daily_click_limit) {
				continue;
			}
		}
		
		// has surfer been to this link?
		$sql2 = "SELECT * FROM click_rotator_stats WHERE click_rotator_links_id = $click_rotator_links_id && surfer_ip = '$surfer_ip_address'";
		$result2 = $mysqli->query($sql2);
		if ($mysqli->connect_errno) {
			echo "Could not select record in click_rotator_stats: (" . $mysqli->errno . ") " . $mysqli->error;
			exit();
		}
		$count2 = $result2->num_rows;
		//$result2->close();
		if ($count2 > 0) {
			continue;
		}
		// did surfer come from this link?
		if ($click_trades_i_code != "") {
			// get click trade record if any
			$sql2 = "SELECT * FROM click_trades WHERE inbound_click_tracking_code = '$click_trades_i_code'";
			$result2 = $mysqli->query($sql2);
			if ($mysqli->connect_errno) {
				echo "Could not select record in click_trades: (" . $mysqli->errno . ") " . $mysqli->error;
				exit();
			}
			$count2 = $result2->num_rows;
			if ($count2 > 0) {
				$row2 = $result2->fetch_array(MYSQLI_BOTH);
				$click_trades_id = $row2['id'];		
				$sql3 = "SELECT * FROM click_trade_stats WHERE click_trades_id = $click_trades_id && inbound_outbound = 'i' && surfer_ip = '$surfer_ip_address'";
				$result3 = $mysqli->query($sql3);
				if ($mysqli->connect_errno) {
					echo "Could not select record in click_trade_stats: (" . $mysqli->errno . ") " . $mysqli->error;
					exit();
				}
				$count3 = $result3->num_rows;
				//$result3->close();
				if ($count3 > 0) {
					//$result2->close();
					continue;
				}
			}
			$result2->close();
		}		
		// found a link to send surfer to
		$destination_url = $link_url;
		$link_found = "Yes";
		break;
	} // end while
	//$result->close();
//echo $link_found;
//echo "<br>";
//echo $destination_url;
//echo "<br>";
//exit;
	if ($link_found == "No") {
		// loop through again
		$sql = "SELECT * FROM click_rotator_links WHERE click_rotators_id = $click_rotators_id && link_status = 'Active' && start_date_time <= now() ORDER BY series_position ASC";
		$result = $mysqli->query($sql);
		if ($mysqli->connect_errno) {
			echo "Could not select record in click_rotator_links: (" . $mysqli->errno . ") " . $mysqli->error;
			exit();
		}
		// loop through links and see if one is found to send surfer (quota not filled)
		// break out when found
		while ($row = $result->fetch_array(MYSQLI_BOTH)) {
			$click_rotator_links_id = $row['id'];
			$series_position = $row['series_position'];
			$link_url = stripslashes($row['link_url']);
			$total_clicks_to_send = $row['total_clicks_to_send'];
			$total_clicks_sent = $row['total_clicks_sent'];
			$date_last_click_sent = $row['date_last_click_sent'];
			$end_date_time = $row['end_date_time'];
			$country_codes_accepted = $row['country_codes_accepted'];
			$country_codes_not_accepted = $row['country_codes_not_accepted'];
			$click_trades_i_code = $row['click_trades_i_code'];
			$daily_click_limit = $row['daily_click_limit'];
			$daily_click_count = $row['daily_click_count'];

			// check end date and time to see if it has passed
			if ($end_date_time != "0000-00-00 00:00:00") {
				if(time() > strtotime($end_date_time)) {
					continue;
				}
			}

			// does rotator link allow or not allow country code?
			// is $country_code blank? then skip this check
			if ($country_code != "") {
				// $country_codes_accepted (not blank)
				if ($country_codes_accepted != "") {
					// is $country_code NOT in $country_codes_accepted
					if(stripos($country_codes_accepted, $country_code) === false) {
						continue;
					}
				}
				// $country_codes_not_accepted (not blank)
				if ($country_codes_not_accepted != "") {
					// is $country_code in $country_codes_not_accepted
					if(stripos($country_codes_not_accepted, $country_code) !== false) {
						continue;
					}
				}
			}
			
			// check quota
			if ($total_clicks_sent >= $total_clicks_to_send) {
				continue;
			}
			
			// check daily click limit
			if ($daily_click_limit > 0) {
				if ($daily_click_count >= $daily_click_limit) {
					continue;
				}
			}
			
			// has surfer been to this link?
			$sql2 = "SELECT * FROM click_rotator_stats WHERE click_rotator_links_id = $click_rotator_links_id && surfer_ip = '$surfer_ip_address'";
			$result2 = $mysqli->query($sql2);
			if ($mysqli->connect_errno) {
				echo "Could not select record in click_rotator_stats: (" . $mysqli->errno . ") " . $mysqli->error;
				exit();
			}
			$count2 = $result2->num_rows;
			//$result2->close();
			if ($count2 > 0) {
				continue;
			}
			// did surfer come from this link?
			if ($click_trades_i_code != "") {
				// get click trade record if any
				$sql2 = "SELECT * FROM click_trades WHERE inbound_click_tracking_code = '$click_trades_i_code'";
				$result2 = $mysqli->query($sql2);
				if ($mysqli->connect_errno) {
					echo "Could not select record in click_trades: (" . $mysqli->errno . ") " . $mysqli->error;
					exit();
				}
				$count2 = $result2->num_rows;
				if ($count2 > 0) {
					$row2 = $result2->fetch_array(MYSQLI_BOTH);
					$click_trades_id = $row2['id'];		
					$sql3 = "SELECT * FROM click_trade_stats WHERE click_trades_id = $click_trades_id && inbound_outbound = 'i' && surfer_ip = '$surfer_ip_address'";
					$result3 = $mysqli->query($sql3);
					if ($mysqli->connect_errno) {
						echo "Could not select record in click_trade_stats: (" . $mysqli->errno . ") " . $mysqli->error;
						exit();
					}
					$count3 = $result3->num_rows;
					//$result3->close();
					if ($count3 > 0) {
						//$result2->close();
						continue;
					}
				}
				//$result2->close();
			}
			// found a link to send surfer to
			$destination_url = $link_url;
			$link_found = "Yes";
			break;
		} // end while
		//$result->close();
	}
}
//echo $link_found;
//echo "<br>";
//echo $destination_url;
//echo "<br>";
//exit;
// was a link found? $link_found == "No";
if ($link_found == "Yes") {
	// process found link
	// update click_rotator_links
	$sql = "UPDATE click_rotator_links SET total_clicks_sent = total_clicks_sent + 1, date_last_click_sent = now(), daily_click_count = daily_click_count + 1 WHERE id = $click_rotator_links_id";
	$result = $mysqli->query($sql);
	if ($mysqli->connect_errno) {
		echo "Could not select record in click_rotator_links: (" . $mysqli->errno . ") " . $mysqli->error;
		exit();
	}
	// insert record click_rotator_stats
	$sql = "INSERT INTO click_rotator_stats (click_rotators_id, click_rotator_links_id, click_date, surfer_ip, referring_url, country_code, country_name, language_code, user_agent, ip_host) values ($click_rotators_id, $click_rotator_links_id, now(), '$surfer_ip_address', '$referring_url', '$country_code', '$country_name', '$accept_language_string', '$user_agent_string', '$ip_host')";
	$result = $mysqli->query($sql);
	if ($mysqli->connect_errno) {
		echo "Could not insert record in click_rotator_stats: (" . $mysqli->errno . ") " . $mysqli->error;
		exit();
	}	
} else {
	// process default url
	$click_rotator_links_id = 0;
	// insert record click_rotator_stats
	$sql = "INSERT INTO click_rotator_stats (click_rotators_id, click_rotator_links_id, click_date, surfer_ip, referring_url, country_code, country_name, language_code, user_agent, ip_host) values ($click_rotators_id, $click_rotator_links_id, now(), '$surfer_ip_address', '$referring_url', '$country_code', '$country_name', '$accept_language_string', '$user_agent_string', '$ip_host')";
	$result = $mysqli->query($sql);
	if ($mysqli->connect_errno) {
		echo "Could not insert record in click_rotator_stats: (" . $mysqli->errno . ") " . $mysqli->error;
		exit();
	}	
}
	
// close up shop
$mysqli->close();

// send to destination url
// redirect to url with a 301
//header("HTTP/1.1 301 Moved Permanently");
header("Location: $destination_url");
exit();

?>
