<?php
header("Cache-Control: no-cache, must-revalidate");
header("Expires: Sat, 26 Jul 1997 05:00:00 GMT");
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache");

// My Click Boss - Version 3.11
// Copyright (c) 2013 by RLW Publishing, all rights reserved.
// http://myclickboss.com/

include "admin/config.inc.php";
include "admin/functions.php";
include("geoip.inc");

$default_404_url = $trades_404_url;

// get a (click_tracking_code)
if (isset($_GET['a'])) {
	$click_tracking_code = $_GET['a'];
} else {
	$click_tracking_code = "";
}

// get surfers IP
$surfer_ip_address = GetUserIP();

// get referring url
if (isset($_SERVER['HTTP_REFERER'])) {
	$referring_url = $_SERVER['HTTP_REFERER'];
} else {
	$referring_url = "";
}

// get $_SERVER['HTTP_ACCEPT_LANGUAGE']
if (isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
	$accept_language_string = $_SERVER['HTTP_ACCEPT_LANGUAGE'];
} else {
	$accept_language_string = "";
}

// get $_SERVER['HTTP_USER_AGENT']
if (isset($_SERVER['HTTP_USER_AGENT'])) {
	$user_agent_string = $_SERVER['HTTP_USER_AGENT'];
} else {
	$user_agent_string = "";
}

// get $_SERVER['REMOTE_HOST']
if (isset($_SERVER['REMOTE_HOST'])) {
	$ip_host = $_SERVER['REMOTE_HOST'];
} else {
	$ip_host = "";
}

// is $click_tracking_code blank?
if ($click_tracking_code == "") {
	// redirect to url with a 301
	//header("HTTP/1.1 301 Moved Permanently");
	header("Location: $default_404_url");
	exit();
}

// $click_tracking_code contain invalid characters?
if(!preg_match('/^[a-z0-9-]+$/', $click_tracking_code)) {
	// redirect to url with a 301
	//header("HTTP/1.1 301 Moved Permanently");
	header("Location: $default_404_url");
	exit();
}

// is code an inbound or outbound code?
// get first character of code
$tracking_code_type = substr($click_tracking_code, 0, 1);
if ($tracking_code_type != "i" && $tracking_code_type != "o") {
	// redirect to url with a 301
	//header("HTTP/1.1 301 Moved Permanently");
	header("Location: $default_404_url");
	exit();
}

// connect to database
$mysqli = new mysqli(HOST, USER, PASSWORD, DATABASE);
if ($mysqli->connect_errno) {
	echo "Failed to connect to MySQL: (" . $mysqli->connect_errno . ") " . $mysqli->connect_error;
	exit();
}

// sanitize all input data
$click_tracking_code = sanitize($click_tracking_code, $mysqli);
$referring_url = sanitize($referring_url, $mysqli);
$accept_language_string = sanitize($accept_language_string, $mysqli);
$user_agent_string = sanitize($user_agent_string, $mysqli);

// lookup $click_tracking_code $tracking_code_type
if ($tracking_code_type == "i") {
	$sql = "SELECT * FROM click_trades WHERE inbound_click_tracking_code = '$click_tracking_code'";
} else {
	$sql = "SELECT * FROM click_trades WHERE outbound_click_tracking_code = '$click_tracking_code'";
}
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Could not select record in click_trades: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}
$count = $result->num_rows;
if ($count < 1) {
	// close up shop
	$mysqli->close();
	// redirect to url with a 301
	//header("HTTP/1.1 301 Moved Permanently");
	header("Location: $default_404_url");
	exit();
}
// get the data for this click_trades
$row = $result->fetch_array(MYSQLI_BOTH);
$click_trades_id = $row['id'];
$description = stripslashes($row['description']);
$trade_partners_url = stripslashes($row['trade_partners_url']);
$my_url = stripslashes($row['my_url']);
$total_clicks_sent = $row['total_clicks_sent'];
$alert_when_number_clicks_sent = $row['alert_when_number_clicks_sent'];
$email_alert_sent = $row['email_alert_sent'];
$result->close();

// get geoip country_code
$gi = geoip_open("$path_to_geoip",GEOIP_STANDARD);
$country_code = geoip_country_code_by_addr($gi, $surfer_ip_address);
$country_name = geoip_country_name_by_addr($gi, $surfer_ip_address);
geoip_close($gi);

// does this click count as a unique IP click? if not record click as duplicate raw
$sql = "SELECT * FROM click_trade_stats WHERE click_trades_id = $click_trades_id && inbound_outbound = '$tracking_code_type' && surfer_ip = '$surfer_ip_address'";
$result = $mysqli->query($sql);
if ($mysqli->connect_errno) {
	echo "Could not select record in click_trade_stats: (" . $mysqli->errno . ") " . $mysqli->error;
	exit();
}
$count = $result->num_rows;
//$result->close();
if ($count < 1) {
	$count_click = "Yes";
} else {
	$count_click = "No";
}

// record click
if ($count_click == "Yes") {	
	// insert into click_trade_stats (i,o)
	$sql = "INSERT INTO click_trade_stats (click_trades_id, inbound_outbound, click_date, surfer_ip, referring_url, country_code, country_name, language_code, user_agent, ip_host) values ($click_trades_id, '$tracking_code_type', now(), '$surfer_ip_address', '$referring_url', '$country_code', '$country_name', '$accept_language_string', '$user_agent_string', '$ip_host')";
	$result = $mysqli->query($sql);
	if ($mysqli->connect_errno) {
		echo "Could not insert record in click_trade_stats: (" . $mysqli->errno . ") " . $mysqli->error;
		exit();
	}

	// update click_trades (i or o)
	if ($tracking_code_type == "i") {
		$sql = "UPDATE click_trades SET total_clicks_received = total_clicks_received + 1 WHERE id = $click_trades_id";
	} else {
		$sql = "UPDATE click_trades SET total_clicks_sent = total_clicks_sent + 1 WHERE id = $click_trades_id";
	}
	$result = $mysqli->query($sql);
	if ($mysqli->connect_errno) {
		echo "Could not update record in click_trades: (" . $mysqli->errno . ") " . $mysqli->error;
		exit();
	}

	// email and set to email sent if number reached and is not 0
	if ($email_alert_sent == "No" && $alert_when_number_clicks_sent > 0 && $tracking_code_type == "o") {
		$total_clicks_sent_now = $total_clicks_sent + 1;
		if ($total_clicks_sent_now >= $alert_when_number_clicks_sent) {
			// get admin email
			$sql = "SELECT * FROM members";
			$result = $mysqli->query($sql);
			if ($mysqli->connect_errno) {
				echo "Could not select record in members: (" . $mysqli->errno . ") " . $mysqli->error;
				exit();
			}
			$row = $result->fetch_array(MYSQLI_BOTH);
			$email = stripslashes($row['email']);
			$result->close();
			// email admin
			$email_template_location = $path_to_alert_email;
			$email_template_handle = fopen($email_template_location, "r");
			$email_template = fread($email_template_handle, filesize($email_template_location));
			fclose($email_template_handle);
			// do placeholder replacements
			$email_template = str_replace("%%description%%", $description, $email_template);
			// fixup email contents
			$email_template = str_replace("\r\n", "\n", $email_template);
			$email_template = nl2br($email_template);				
			// send email
			$e_headers = "From: My Click Boss <noreply@myclickboss.com>\n";
			$e_headers .= "Content-Type: text/html; charset=iso-8859-1\n";
			$e_recipient = "$email";
			$e_subject = "My Click Boss Alert";
			$e_message = $email_template;
			mail($e_recipient, $e_subject, $e_message, $e_headers);
			// set to email sent
			$sql_t3 = "UPDATE click_trades SET email_alert_sent = 'Yes' WHERE id = $click_trades_id";
			$result_t3 = $mysqli->query($sql_t3);
			if ($mysqli->connect_errno) {
				echo "Could not update record in click_trades: (" . $mysqli->errno . ") " . $mysqli->error;
				exit();
			}
		}
	}
} else {
	// duplicate IP click (raw)
	// insert into click_trade_raw_stats (i,o)
	$sql = "INSERT INTO click_trade_raw_stats (click_trades_id, inbound_outbound, click_date, surfer_ip, referring_url, country_code, country_name, language_code, user_agent, ip_host) values ($click_trades_id, '$tracking_code_type', now(), '$surfer_ip_address', '$referring_url', '$country_code', '$country_name', '$accept_language_string', '$user_agent_string', '$ip_host')";
	$result = $mysqli->query($sql);
	if ($mysqli->connect_errno) {
		echo "Could not insert record in click_trade_raw_stats: (" . $mysqli->errno . ") " . $mysqli->error;
		exit();
	}	
}

// set destination url
if ($tracking_code_type == "i") {
	$destination_url = $my_url;
} else {
	$destination_url = $trade_partners_url;
}

// close up shop
$mysqli->close();

// send to destination url
// redirect to url with a 301
//header("HTTP/1.1 301 Moved Permanently");
header("Location: $destination_url");
exit();

?>

